@@ -30,6 +30,7 @@ __all__ = [
     "Authorization",
     "SendAuthorization",
     "GenericAuthorization",
+    "StakeAuthorization",
     "AuthorizationGrant",
     "AuthorizationType",
 ]
@@ -56,6 +57,12 @@ class Authorization(BaseTerraData):
 
         return parse_authorization_proto(proto)
 
+    @staticmethod
+    def unpack_any(proto: Any_pb) -> Authorization:
+        from terra_sdk.util.parse_authorization import parse_authorization_unpack_any
+
+        return parse_authorization_unpack_any(proto)
+
 
 @attr.s
 class SendAuthorization(Authorization):
@@ -69,9 +76,13 @@ class SendAuthorization(Authorization):
     type_amino = "msgauth/SendAuthorization"
     """"""
     type_url = "/cosmos.bank.v1beta1.SendAuthorization"
+    """"""
+    prototype = SendAuthorization_pb
+    """"""
 
     spend_limit: Coins = attr.ib(converter=Coins)
 
+
     def to_amino(self) -> dict:
         return {
             "type": self.type_amino,
@@ -97,6 +108,8 @@ class SendAuthorization(Authorization):
         value = amino["value"]
         return cls(spend_limit=Coins.from_amino(value["spend_limit"]))
 
+    def pack_any(self) -> Any_pb:
+        return Any_pb(type_url=self.type_url, value=bytes(self.to_proto()))
 
 
 @attr.s
@@ -104,16 +117,19 @@ class GenericAuthorization(Authorization):
     """Generic type of :class:`Authorization`, specifying the type of message to allow.
 
     Args:
-        grant_msg_type: type of message allowed by authorization"""
+        msg: type of message allowed by authorization"""
 
     type_amino = "msgauth/GenericAuthorization"
     """"""
     type_url = "/cosmos.authz.v1beta1.GenericAuthorization"
+    """"""
+    prototype = GenericAuthorization_pb
+    """"""
 
     msg: str = attr.ib()
 
     def to_amino(self) -> dict:
-        return {"type": self.type_amino, "value": {"msg": self.msg()}}
+        return {"type": self.type_amino, "value": {"msg": self.msg}}
 
     def to_data(self) -> dict:
         return {"@type": self.type_url, "msg": self.msg}
@@ -130,10 +146,13 @@ class GenericAuthorization(Authorization):
         return cls(msg=proto.msg)
 
     @classmethod
-    def from_amino(cls, amino: dict) -> SendAuthorization:
+    def from_amino(cls, amino: dict) -> GenericAuthorization:
         value = amino["value"]
         return cls(msg=value["msg"])
 
+    def pack_any(self) -> Any_pb:
+        return Any_pb(type_url=self.type_url, value=bytes(self.to_proto()))
+
 
 @attr.s
 class AuthorizationGrant(JSONSerializable):
@@ -142,7 +161,7 @@ class AuthorizationGrant(JSONSerializable):
     authorization: Authorization = attr.ib()
     """Grant authorization details."""
 
-    expiration: datetime = attr.ib(converter=parser.parse)
+    expiration: datetime = attr.ib()
     """Grant expiration."""
 
     def to_amino(self) -> dict:
@@ -166,23 +185,23 @@ class AuthorizationGrant(JSONSerializable):
 
     def to_proto(self) -> Grant_pb:
         return Grant_pb(
-            authorization=self.authorization.to_proto(),
+            authorization=self.authorization.pack_any(),
             expiration=self.expiration,
         )
 
     @classmethod
     def from_proto(cls, proto: Grant_pb) -> AuthorizationGrant:
         return cls(
-            authorization=Authorization.from_proto(proto.authorization),
-            expiration=parser.parse(proto.expiration),
+            authorization=Authorization.unpack_any(proto.authorization),
+            expiration=proto.expiration,
         )
 
     @classmethod
     def from_amino(cls, amino: dict) -> AuthorizationGrant:
         value = amino["value"]
         return cls(
-            authorization=Authorization.from_amino(amino["authorization"]),
-            expiration=amino["expiration"]
+            authorization=Authorization.from_amino(value["authorization"]),
+            expiration=parser.parse(value["expiration"])
         )
 
 
@@ -211,11 +230,14 @@ class StakeAuthorizationValidators(JSONSerializable):
 @attr.s
 class StakeAuthorization(Authorization):
     authorization_type: AuthorizationType = attr.ib()
-    max_tokens: Optional[Coin] = attr.ib(converter=Coin.parse, default=None)
+    max_tokens: Optional[Coin] = attr.ib(default=None)
     allow_list: Optional[StakeAuthorizationValidators] = attr.ib(default=None)
     deny_list: Optional[StakeAuthorizationValidators] = attr.ib(default=None)
 
     type_url = "/cosmos.staking.v1beta1.StakeAuthorization"
+    """"""
+    prototype = StakeAuthorization_pb
+    """"""
 
     def to_amino(self):
         raise Exception("Amino not supported")
@@ -233,15 +255,9 @@ class StakeAuthorization(Authorization):
     def from_data(cls, data: dict) -> StakeAuthorization:
         return StakeAuthorization(
             authorization_type=data["authorization_type"],
-            max_tokens=Coins.from_data(data["max_tokens"])
-            if data.get("max_tokens")
-            else None,
-            allow_list=StakeAuthorizationValidators.from_data(data["allow_list"])
-            if data.get("allow_list")
-            else None,
-            deny_list=StakeAuthorizationValidators.from_data(data["deny_list"])
-            if data.get("deny_list")
-            else None,
+            max_tokens=(Coin.from_data(data["max_tokens"]) if data.get("max_tokens") is not None else None),
+            allow_list=StakeAuthorizationValidators.from_data(data["allow_list"]) if data.get("allow_list") else None,
+            deny_list=StakeAuthorizationValidators.from_data(data["deny_list"]) if data.get("deny_list") else None,
         )
 
     def to_proto(self) -> StakeAuthorization_pb:
@@ -256,13 +272,10 @@ class StakeAuthorization(Authorization):
     def from_proto(cls, proto: StakeAuthorization_pb) -> StakeAuthorization:
         return StakeAuthorization(
             authorization_type=proto.authorization_type,
-            max_tokens=Coins.from_proto(proto.max_tokens)
-            if proto.max_tokens
-            else None,
-            allow_list=StakeAuthorizationValidators.from_proto(proto.allow_list)
-            if proto.allow_list
-            else None,
-            deny_list=StakeAuthorizationValidators.from_proto(proto.deny_list)
-            if proto.deny_list
-            else None,
+            max_tokens=Coin.from_proto(proto.max_tokens) if proto.max_tokens else None,
+            allow_list=StakeAuthorizationValidators.from_proto(proto.allow_list) if proto.allow_list else None,
+            deny_list=StakeAuthorizationValidators.from_proto(proto.deny_list) if proto.deny_list else None,
         )
+
+    def pack_any(self) -> Any_pb:
+        return Any_pb(type_url=self.type_url, value=bytes(self.to_proto()))
