@@ -2,13 +2,15 @@
 
 from __future__ import annotations
 
-from typing import Any, List
+from typing import List
 
 from terra_proto.cosmos.bank.v1beta1 import Input as Input_pb
 from terra_proto.cosmos.bank.v1beta1 import MsgMultiSend as MsgMultiSend_pb
 from terra_proto.cosmos.bank.v1beta1 import MsgSend as MsgSend_pb
 from terra_proto.cosmos.bank.v1beta1 import Output as Output_pb
 
+from betterproto.lib.google.protobuf import Any as Any_pb
+
 from terra_sdk.core import AccAddress, Coins
 from terra_sdk.core.msg import Msg
 from terra_sdk.util.json import JSONSerializable
@@ -20,12 +22,11 @@ import attr
 
 @attr.s
 class MsgSend(Msg):
-    """Sends native Terra assets (Luna or Terra stablecoins) from ``from_address`` to
-    ``to_address``.
+    """Sends native Terra assets (Luna or Terra stablecoins) from ``from_address`` to ``to_address``.
 
     Args:
-        from_address: sender
-        to_address: recipient
+        from_address (AccAddress): sender
+        to_address (AccAddress): recipient
         amount (Coins): coins to send
     """
 
@@ -35,6 +36,8 @@ class MsgSend(Msg):
     """"""
     action = "send"
     """"""
+    prototype = MsgSend_pb
+    """"""
 
     from_address: AccAddress = attr.ib()
     to_address: AccAddress = attr.ib()
@@ -81,10 +84,6 @@ class MsgSend(Msg):
         proto.amount = [c.to_proto() for c in self.amount]
         return proto
 
-    @classmethod
-    def unpack_any(cls, any: Any) -> MsgSend:
-        return MsgSend.from_proto(any)
-
 
 @attr.s
 class MultiSendInput(JSONSerializable):
@@ -191,6 +190,8 @@ class MsgMultiSend(Msg):
     """"""
     action = "multisend"
     """"""
+    prototype = MsgMultiSend_pb
+    """"""
 
     inputs: List[MultiSendInput] = attr.ib(converter=convert_input_list)
     outputs: List[MultiSendOutput] = attr.ib(converter=convert_output_list)
@@ -230,3 +231,7 @@ class MsgMultiSend(Msg):
             inputs=[i.to_proto() for i in self.inputs],
             outputs=[o.to_proto() for o in self.outputs],
         )
+
+    @classmethod
+    def unpack_any(cls, any_pb: Any_pb) -> MsgMultiSend:
+        return cls.from_proto(MsgMultiSend_pb().parse(any_pb))
