@@ -1,57 +1,23 @@
 """Gov module data types."""
 
 from __future__ import annotations
-
-import copy
 from datetime import datetime
-from typing import List, Union
-
+from typing import List
 import attr
 from dateutil import parser
-from terra_proto.cosmos.gov.v1beta1 import Proposal as Proposal_pb
+
+from terra_proto.cosmos.gov.v1beta1 import Proposal as Proposal_pb, ProposalStatus
 from terra_proto.cosmos.gov.v1beta1 import TallyResult as TallyResult_pb
 from terra_proto.cosmos.gov.v1beta1 import Vote as Vote_pb
 from terra_proto.cosmos.gov.v1beta1 import VoteOption
 from terra_proto.cosmos.gov.v1beta1 import WeightedVoteOption as WeightedVoteOption_pb
 
 from terra_sdk.core import AccAddress, Coins
-from terra_sdk.core.distribution import CommunityPoolSpendProposal
-from terra_sdk.core.params import ParameterChangeProposal
-from terra_sdk.core.upgrade import (
-    CancelSoftwareUpgradeProposal,
-    SoftwareUpgradeProposal,
-)
-from terra_sdk.util.json import JSONSerializable, dict_to_data
+from terra_sdk.util.json import JSONSerializable
+from terra_sdk.util.converter import to_isoformat
+from terra_sdk.util.parse_content import parse_content, Content
 
-from .proposals import TextProposal
-
-__all__ = ["Proposal", "Content", "VoteOption", "WeightedVoteOption"]
-
-from ...util.converter import to_isoformat
-
-Content = Union[
-    TextProposal,
-    CommunityPoolSpendProposal,
-    ParameterChangeProposal,
-    SoftwareUpgradeProposal,
-    CancelSoftwareUpgradeProposal,
-]
-
-
-def Content_from_data(data: dict) -> Content:
-    typ = data["@type"]
-    if typ == TextProposal.type_url:
-        return TextProposal.from_data(data)
-    elif typ == CommunityPoolSpendProposal.type_url:
-        return CommunityPoolSpendProposal.from_data(data)
-    elif typ == ParameterChangeProposal.type_url:
-        return ParameterChangeProposal.from_data(data)
-    elif typ == SoftwareUpgradeProposal.type_url:
-        return SoftwareUpgradeProposal.from_data(data)
-    elif typ == CancelSoftwareUpgradeProposal.type_url:
-        return CancelSoftwareUpgradeProposal.from_data(data)
-    else:
-        raise ValueError("content type is invalid")
+__all__ = ["Proposal", "Content", "VoteOption", "WeightedVoteOption", "ProposalStatus"]
 
 
 @attr.s
@@ -126,11 +92,6 @@ class Proposal(JSONSerializable):
     voting_end_time: datetime = attr.ib(converter=parser.parse)
     """Time at which voting period ended, or will end."""
 
-    def to_data(self) -> dict:
-        d = copy.deepcopy(self.__dict__)
-        d["id"] = str(d["id"])
-        return dict_to_data(d)
-
     def to_amino(self) -> dict:
         return {
             "proposal_id": str(self.proposal_id),
@@ -148,21 +109,21 @@ class Proposal(JSONSerializable):
     def from_data(cls, data: dict) -> Proposal:
         return cls(
             proposal_id=data["proposal_id"],
-            content=Content_from_data(data["content"]),
+            content=parse_content(data["content"]),
             status=data["status"],
             final_tally_result=data["final_tally_result"],
-            submit_time=data["submit_time"],
-            deposit_end_time=data["deposit_end_time"],
+            submit_time=parser.parse(data["submit_time"]),
+            deposit_end_time=parser.parse(data["deposit_end_time"]),
             total_deposit=Coins.from_data(data["total_deposit"]),
-            voting_start_time=data["voting_start_time"],
-            voting_end_time=data["voting_end_time"],
+            voting_start_time=parser.parse(data["voting_start_time"]),
+            voting_end_time=parser.parse(data["voting_end_time"]),
         )
 
     def to_proto(self) -> Proposal_pb:
         return Proposal_pb(
             proposal_id=self.proposal_id,
             content=self.content.pack_any(),
-            status=self.status,
+            status=ProposalStatus.from_str(self.status),
             final_tally_result=self.final_tally_result.to_proto(),
             submit_time=self.submit_time,
             deposit_end_time=self.deposit_end_time,
