@@ -45,6 +45,8 @@ class MsgChannelOpenInit(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelOpenInit"
     """"""
+    prototype = MsgChannelOpenInit_pb
+    """"""
 
     port_id: str = attr.ib()
     channel: Channel = attr.ib()
@@ -70,7 +72,7 @@ class MsgChannelOpenInit(Msg):
     def from_proto(cls, proto: MsgChannelOpenInit_pb) -> MsgChannelOpenInit:
         return cls(
             port_id=proto.port_id,
-            channel=Channel.from_proto(proto.port_id),
+            channel=Channel.from_proto(proto.channel),
             signer=proto.signer,
         )
 
@@ -84,6 +86,8 @@ class MsgChannelOpenTry(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelOpenTry"
     """"""
+    prototype = MsgChannelOpenTry_pb
+    """"""
 
     port_id: str = attr.ib()
     previous_channel_id: str = attr.ib()
@@ -140,6 +144,8 @@ class MsgChannelOpenAck(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelOpenAck"
     """"""
+    prototype = MsgChannelOpenAck_pb
+    """"""
 
     port_id: str = attr.ib()
     channel_id: str = attr.ib()
@@ -197,6 +203,8 @@ class MsgChannelOpenConfirm(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelOpenConfirm"
     """"""
+    prototype = MsgChannelOpenConfirm_pb
+    """"""
 
     port_id: str = attr.ib()
     channel_id: str = attr.ib()
@@ -243,6 +251,8 @@ class MsgChannelCloseInit(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelCloseInit"
     """"""
+    prototype = MsgChannelCloseInit_pb
+    """"""
 
     port_id: str = attr.ib()
     channel_id: str = attr.ib()
@@ -280,6 +290,8 @@ class MsgChannelCloseConfirm(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgChannelCloseConfirm"
     """"""
+    prototype = MsgChannelCloseConfirm_pb
+    """"""
 
     port_id: str = attr.ib()
     channel_id: str = attr.ib()
@@ -328,6 +340,8 @@ class MsgRecvPacket(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgRecvPacket"
     """"""
+    prototype = MsgRecvPacket_pb
+    """"""
 
     packet: Packet = attr.ib()
     proof_commitment: bytes = attr.ib()
@@ -372,6 +386,8 @@ class MsgTimeout(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgTimeout"
     """"""
+    prototype = MsgTimeout_pb
+    """"""
 
     packet: Packet = attr.ib()
     proof_unreceived: bytes = attr.ib()
@@ -420,6 +436,8 @@ class MsgAcknowledgement(Msg):
 
     type_url = "/ibc.core.channel.v1.MsgAcknowledgement"
     """"""
+    prototype = MsgAcknowledgement_pb
+    """"""
 
     packet: Packet = attr.ib()
     acknowledgement: bytes = attr.ib()
