@@ -29,6 +29,8 @@ class MsgCreateClient(Msg):
 
     type_url = "/ibc.core.client.v1.MsgCreateClient"
     """"""
+    prototype = MsgCreateClient_pb
+    """"""
 
     client_state: dict = attr.ib()
     consensus_state: dict = attr.ib()
@@ -64,11 +66,13 @@ class MsgCreateClient(Msg):
 @attr.s
 class MsgUpdateClient(Msg):
     """
-    MsgUpdateClient defines an sdk.Msg to update a IBC client state using the given header.
+    MsgUpdateClient defines a sdk.Msg to update an IBC client state using the given header.
     """
 
     type_url = "/ibc.core.client.v1.MsgUpdateClient"
     """"""
+    prototype = MsgUpdateClient_pb
+    """"""
 
     client_id: str = attr.ib()
     header: dict = attr.ib()
@@ -107,6 +111,8 @@ class MsgUpgradeClient(Msg):
 
     type_url = "/ibc.core.client.v1.MsgUpgradeClient"
     """"""
+    prototype = MsgUpgradeClient_pb
+    """"""
 
     client_id: str = attr.ib()
     client_state: dict = attr.ib()
@@ -154,14 +160,16 @@ class MsgUpgradeClient(Msg):
 @attr.s
 class MsgSubmitMisbehaviour(Msg):
     """
-    MsgSubmitMisbehaviour defines an sdk.Msg type that submits Evidence for light client misbehaviour.
+    MsgSubmitMisbehaviour defines a sdk.Msg type that submits Evidence for light client misbehaviour.
     """
 
     type_url = "/ibc.core.client.v1.MsgSubmitMisbehaviour"
     """"""
+    prototype = MsgSubmitMisbehaviour_pb
+    """"""
 
     client_id: str = attr.ib()
-    misbehaviour: dict = attr.ib()
+    misbehaviour: any = attr.ib()
     signer: str = attr.ib()
 
     def to_amino(self):
