@@ -40,6 +40,8 @@ class MsgConnectionOpenInit(Msg):
 
     type_url = "/ibc.core.connection.v1.MsgConnectionOpenInit"
     """"""
+    prototype = MsgConnectionOpenInit_pb
+    """"""
 
     client_id: str = attr.ib()
     counterparty: Counterparty = attr.ib()
@@ -88,6 +90,8 @@ class MsgConnectionOpenTry(Msg):
 
     type_url = "/ibc.core.connection.v1.MsgConnectionOpenTry"
     """"""
+    prototype = MsgConnectionOpenTry_pb
+    """"""
 
     client_id: str = attr.ib()
     previous_connection_id: str = attr.ib()
@@ -170,11 +174,13 @@ class MsgConnectionOpenAck(Msg):
 
     type_url = "/ibc.core.connection.v1.MsgConnectionOpenAck"
     """"""
+    prototype = MsgConnectionOpenAck_pb
+    """"""
 
     connection_id: str = attr.ib()
     counterparty_connection_id: str = attr.ib()
     version: Version = attr.ib()
-    client_state: dict = attr.ib()
+    client_state: any = attr.ib()
     proof_height: Height = attr.ib()
     proof_try: bytes = attr.ib()
     proof_client: bytes = attr.ib()
@@ -238,6 +244,8 @@ class MsgConnectionOpenConfirm(Msg):
 
     type_url = "/ibc.core.connection.v1.MsgConnectionOpenConfirm"
     """"""
+    prototype = MsgConnectionOpenConfirm_pb
+    """"""
 
     def to_amino(self):
         raise Exception("Amino not supported")
