@@ -46,6 +46,8 @@ class MsgBeginRedelegate(Msg):
     """"""
     action = "begin_redelegate"
     """"""
+    prototype = MsgBeginRedelegate_pb
+    """"""
 
     delegator_address: AccAddress = attr.ib()
     validator_src_address: ValAddress = attr.ib()
@@ -106,6 +108,8 @@ class MsgDelegate(Msg):
     """"""
     action = "delegate"
     """"""
+    prototype = MsgDelegate_pb
+    """"""
 
     delegator_address: AccAddress = attr.ib()
     validator_address: ValAddress = attr.ib()
@@ -161,6 +165,8 @@ class MsgUndelegate(Msg):
     """"""
     action = "begin_unbonding"
     """"""
+    prototype = MsgUndelegate_pb
+    """"""
 
     delegator_address: AccAddress = attr.ib()
     validator_address: ValAddress = attr.ib()
@@ -217,6 +223,8 @@ class MsgEditValidator(Msg):
     """"""
     action = "edit_validator"
     """"""
+    prototype = MsgEditValidator_pb
+    """"""
 
     description: Description = attr.ib()
     validator_address: ValAddress = attr.ib()
@@ -276,6 +284,8 @@ class MsgCreateValidator(Msg):
     """"""
     action = "create_validator"
     """"""
+    prototype = MsgCreateValidator_pb
+    """"""
 
     description: Description = attr.ib()
     commission: CommissionRates = attr.ib()
