@@ -7,6 +7,7 @@ import json
 from typing import Dict, List, Optional
 
 import attr
+from betterproto.lib.google.protobuf import Any
 from terra_proto.cosmos.base.abci.v1beta1 import AbciMessageLog as AbciMessageLog_pb
 from terra_proto.cosmos.base.abci.v1beta1 import Attribute as Attribute_pb
 from terra_proto.cosmos.base.abci.v1beta1 import StringEvent as StringEvent_pb
@@ -58,9 +59,9 @@ class Tx(JSONSerializable):
     """Data structure for a transaction which can be broadcasted.
 
     Args:
-        body: the processable content of the transaction
-        auth_info: the authorization related content of the transaction
-        signatures: signatures is a list of signatures that matches the length and order of body and auth_info
+        body (TxBody): the processable content of the transaction
+        auth_info (AuthInfo): the authorization related content of the transaction
+        signatures (List[bytes]): signatures is a list of signatures that matches the length and order of body and auth_info
     """
 
     body: TxBody = attr.ib()
@@ -71,22 +72,22 @@ class Tx(JSONSerializable):
         return {
             "body": self.body.to_data(),
             "auth_info": self.auth_info.to_data(),
-            "signatures": [base64.b64encode(sig).decode() for sig in self.signatures],
+            "signatures": [base64.b64encode(sig).decode('ascii') for sig in self.signatures],
         }
 
     def to_proto(self) -> Tx_pb:
-        proto = Tx_pb()
-        proto.body = self.body.to_proto()
-        proto.auth_info = self.auth_info.to_proto()
-        proto.signatures = [sig for sig in self.signatures]
-        return proto
+        return Tx_pb(
+            body=self.body.to_proto(),
+            auth_info=self.auth_info.to_proto(),
+            signatures=self.signatures
+        )
 
     @classmethod
     def from_data(cls, data: dict) -> Tx:
         return cls(
             TxBody.from_data(data["body"]),
             AuthInfo.from_data(data["auth_info"]),
-            data["signatures"],
+            [base64.b64decode(sig) for sig in data["signatures"]],
         )
 
     @classmethod
@@ -189,7 +190,7 @@ class TxBody(JSONSerializable):
     @classmethod
     def from_proto(cls, proto: TxBody_pb) -> TxBody:
         return cls(
-            [parse_proto(m) for m in proto.messages],
+            [Msg.unpack_any(m) for m in proto.messages],
             proto.memo,
             proto.timeout_height,
         )
@@ -447,14 +448,14 @@ class TxInfo(JSONSerializable):
     @classmethod
     def from_data(cls, data: dict) -> TxInfo:
         return cls(
-            data["height"],
-            data["txhash"],
-            data["raw_log"],
+            data.get("height"),
+            data.get("txhash"),
+            data.get("raw_log"),
             parse_tx_logs(data.get("logs")),
-            data["gas_wanted"],
-            data["gas_used"],
-            Tx.from_data(data["tx"]),
-            data["timestamp"],
+            data.get("gas_wanted"),
+            data.get("gas_used"),
+            Tx.from_data(data.get("tx")),
+            data.get("timestamp"),
             data.get("code"),
             data.get("codespace"),
         )
