@@ -40,9 +40,7 @@ class Plan(JSONSerializable):
             time=parse(data["time"]) if data.get("time") else None,
             height=data["height"],
             info=data["info"],
-            upgrade_client_state=data["upgrade_client_state"]
-            if data.get("upgrade_client_state")
-            else None,
+            upgrade_client_state=data["upgrade_client_state"] if data.get("upgrade_client_state") else None,
         )
 
     def to_proto(self) -> Plan_pb:
@@ -56,3 +54,13 @@ class Plan(JSONSerializable):
             info=self.info,
             upgraded_client_state=ucs if ucs else None,
         )
+
+    @classmethod
+    def from_proto(cls, proto: Plan_pb) -> Plan:
+        return cls(
+            name=proto.name,
+            time=parse(proto.time) if proto.time else None,
+            height=proto.height,
+            info=proto.info,
+            upgrade_client_state=Any_pb().parse(proto.upgrade_client_state) if proto.upgraded_client_state else None,
+        )
