@@ -3,9 +3,8 @@
 from __future__ import annotations
 
 import base64
-import copy
 import json
-from typing import Optional
+from typing import Optional, Union
 
 import attr
 from terra_proto.terra.wasm.v1beta1 import (
@@ -25,7 +24,6 @@ from betterproto.lib.google.protobuf import Any as Any_pb
 
 from terra_sdk.core import AccAddress, Coins
 from terra_sdk.core.msg import Msg
-from terra_sdk.util.json import dict_to_data
 from terra_sdk.util.remove_none import remove_none
 
 __all__ = [
@@ -39,6 +37,12 @@ __all__ = [
 ]
 
 
+def parse_msg(msg: Union[dict, str, bytes]) -> dict:
+    if type(msg) is dict:
+        return msg
+    return json.loads(msg)
+
+
 @attr.s
 class MsgStoreCode(Msg):
     """Upload a new smart contract WASM binary to the blockchain.
@@ -52,6 +56,8 @@ class MsgStoreCode(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgStoreCode"
     """"""
+    prototype = MsgStoreCode_pb
+    """"""
 
     sender: AccAddress = attr.ib()
     wasm_byte_code: str = attr.ib()
@@ -73,7 +79,7 @@ class MsgStoreCode(Msg):
 
     @classmethod
     def from_proto(cls, proto: MsgStoreCode_pb) -> MsgStoreCode:
-        return cls(sender=proto.sender, wasm_byte_code=proto.wasm_byte_code)
+        return cls(sender=proto.sender, wasm_byte_code=base64.b64encode(proto.wasm_byte_code).decode())
 
 
 @attr.s
@@ -91,6 +97,8 @@ class MsgMigrateCode(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgMigrateCode"
     """"""
+    prototype = MsgMigrateCode_pb
+    """"""
 
     sender: AccAddress = attr.ib()
     code_id: int = attr.ib(converter=int)
@@ -106,13 +114,6 @@ class MsgMigrateCode(Msg):
             },
         }
 
-    def to_data(self) -> dict:
-        d = copy.deepcopy(self.__dict__)
-        d["sender"] = str(d["sender"])
-        d["code_id"] = str(d["code_id"])
-        d["wasm_byte_code"] = str(d["wasm_byte_code"])
-        return {"type": self.type_url, "value": dict_to_data(d)}
-
     @classmethod
     def from_data(cls, data: dict) -> MsgMigrateCode:
         return cls(
@@ -123,7 +124,7 @@ class MsgMigrateCode(Msg):
 
     def to_proto(self) -> MsgMigrateCode_pb:
         return MsgMigrateCode_pb(
-            sender=self.sender, code_id=self.code_id, wasm_byte_code=self.wasm_byte_code
+            sender=self.sender, code_id=self.code_id, wasm_byte_code=base64.b64decode(self.wasm_byte_code)
         )
 
     @classmethod
@@ -131,7 +132,7 @@ class MsgMigrateCode(Msg):
         return cls(
             sender=proto.sender,
             code_id=proto.code_id,
-            wasm_byte_code=proto.wasm_byte_code,
+            wasm_byte_code=base64.b64encode(proto.wasm_byte_code).decode(),
         )
 
 
@@ -143,7 +144,7 @@ class MsgInstantiateContract(Msg):
         sender: address of sender
         admin: address of contract admin
         code_id (int): code ID to use for instantiation
-        init_msg (dict): InitMsg to initialize contract
+        init_msg (dict|str): InitMsg to initialize contract
         init_coins (Coins): initial amount of coins to be sent to contract
     """
 
@@ -151,11 +152,13 @@ class MsgInstantiateContract(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgInstantiateContract"
     """"""
+    prototype = MsgInstantiateContract_pb
+    """"""
 
     sender: AccAddress = attr.ib()
     admin: Optional[AccAddress] = attr.ib()
     code_id: int = attr.ib(converter=int)
-    init_msg: dict = attr.ib()
+    init_msg: Union[dict, str] = attr.ib()
     init_coins: Coins = attr.ib(converter=Coins, factory=Coins)
 
     def to_amino(self) -> dict:
@@ -165,23 +168,18 @@ class MsgInstantiateContract(Msg):
                 "sender": self.sender,
                 "admin": self.admin,
                 "code_id": str(self.code_id),
-                "init_msg": self.init_msg,
+                "init_msg": remove_none(self.init_msg),
                 "init_coins": self.init_coins.to_amino(),
             },
         }
 
-    def to_data(self) -> dict:
-        d = copy.deepcopy(self.__dict__)
-        d["code_id"] = str(d["code_id"])
-        return {"type": self.type_url, "value": dict_to_data(d)}
-
     @classmethod
     def from_data(cls, data: dict) -> MsgInstantiateContract:
         return cls(
             sender=data.get("sender"),
             admin=data.get("admin"),
             code_id=data["code_id"],
-            init_msg=remove_none(data["init_msg"]),
+            init_msg=parse_msg(data["init_msg"]),
             init_coins=Coins.from_data(data["init_coins"]),
         )
 
@@ -200,7 +198,7 @@ class MsgInstantiateContract(Msg):
             sender=proto.sender,
             admin=proto.admin,
             code_id=proto.code_id,
-            init_msg=remove_none(proto.init_msg),
+            init_msg=parse_msg(proto.init_msg),
             init_coins=Coins.from_proto(proto.init_coins),
         )
 
@@ -212,7 +210,7 @@ class MsgExecuteContract(Msg):
     Args:
         sender: address of sender
         contract: address of contract to execute function on
-        execute_msg (dict): ExecuteMsg to pass
+        execute_msg (dict|str): ExecuteMsg to pass
         coins: coins to be sent, if needed by contract to execute.
             Defaults to empty ``Coins()``
     """
@@ -221,10 +219,12 @@ class MsgExecuteContract(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgExecuteContract"
     """"""
+    prototype = MsgExecuteContract_pb
+    """"""
 
     sender: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
-    execute_msg: dict = attr.ib()
+    execute_msg: Union[dict, str] = attr.ib()
     coins: Coins = attr.ib(converter=Coins, factory=Coins)
 
     def to_amino(self) -> dict:
@@ -243,7 +243,7 @@ class MsgExecuteContract(Msg):
         return cls(
             sender=data["sender"],
             contract=data["contract"],
-            execute_msg=remove_none(data.get("execute_msg")),
+            execute_msg=parse_msg(data["execute_msg"]),
             coins=Coins.from_data(data["coins"]),
         )
 
@@ -257,11 +257,10 @@ class MsgExecuteContract(Msg):
 
     @classmethod
     def from_proto(cls, proto: Any_pb) -> MsgExecuteContract:
-        proto = MsgExecuteContract_pb.parse(proto.value)
         return cls(
             sender=proto.sender,
             contract=proto.contract,
-            execute_msg=remove_none(proto.execute_msg),
+            execute_msg=parse_msg(proto.execute_msg),
             coins=Coins.from_proto(proto.coins),
         )
 
@@ -274,18 +273,20 @@ class MsgMigrateContract(Msg):
         admin: address of contract admin
         contract: address of contract to migrate
         new_code_id (int): new code ID to migrate to
-        migrate_msg (dict): MigrateMsg to execute
+        migrate_msg (dict|str): MigrateMsg to execute
     """
 
     type_amino = "wasm/MsgMigrateContract"
     """"""
     type_url = "/terra.wasm.v1beta1.MsgMigrateContract"
     """"""
+    prototype = MsgMigrateContract_pb
+    """"""
 
     admin: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
     new_code_id: int = attr.ib(converter=int)
-    migrate_msg: dict = attr.ib()
+    migrate_msg: Union[dict, str] = attr.ib()
 
     def to_amino(self) -> dict:
         return {
@@ -298,17 +299,13 @@ class MsgMigrateContract(Msg):
             },
         }
 
-    def to_data(self) -> dict:
-        d = copy.deepcopy(self.__dict__)
-        return {"type": self.type_url, "value": dict_to_data(d)}
-
     @classmethod
     def from_data(cls, data: dict) -> MsgMigrateContract:
         return cls(
             admin=data["admin"],
             contract=data["contract"],
             new_code_id=data["new_code_id"],
-            migrate_msg=data["migrate_msg"],
+            migrate_msg=parse_msg(data["migrate_msg"]),
         )
 
     def to_proto(self) -> MsgMigrateContract_pb:
@@ -325,7 +322,7 @@ class MsgMigrateContract(Msg):
             admin=proto.admin,
             contract=proto.contract,
             new_code_id=proto.new_code_id,
-            migrate_msg=proto.migrate_msg,
+            migrate_msg=parse_msg(proto.migrate_msg),
         )
 
 
@@ -343,6 +340,8 @@ class MsgUpdateContractAdmin(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgUpdateContractAdmin"
     """"""
+    prototype = MsgUpdateContractAdmin_pb
+    """"""
 
     admin: AccAddress = attr.ib()
     new_admin: AccAddress = attr.ib()
@@ -393,6 +392,8 @@ class MsgClearContractAdmin(Msg):
     """"""
     type_url = "/terra.wasm.v1beta1.MsgClearContractAdmin"
     """"""
+    prototype = MsgClearContractAdmin_pb
+    """"""
 
     admin: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
