@@ -10,10 +10,16 @@ from terra_sdk.util.converter import to_isoformat
 def to_data(x: Any) -> Any:
     if "to_data" in dir(x):
         return x.to_data()
+    if isinstance(x, int):
+        return str(x)
+    if isinstance(x, datetime):
+        return to_isoformat(x)
     if isinstance(x, list):
         return [to_data(g) for g in x]
     if isinstance(x, dict):
         return dict_to_data(x)
+    if isinstance(x, datetime):
+        return to_isoformat(x)
     return x
 
 
@@ -22,6 +28,8 @@ def to_amino(x: Any) -> Any:
         return x.to_amino()
     if isinstance(x, list):
         return [to_data(g) for g in x]
+    if isinstance(x, datetime):
+        return to_isoformat(x)
     if isinstance(x, dict):
         return dict_to_amino(x)
     if isinstance(x, int):
@@ -42,7 +50,7 @@ def dict_to_data(d: dict) -> dict:
 class JSONSerializable(ABC):
     def to_data(self) -> Any:
         """Converts the object to its JSON-serializable Python data representation."""
-        return dict_to_data(copy.deepcopy(self.__dict__))
+        pass  # return dict_to_data(copy.deepcopy(self.__dict__))
 
     def to_json(self) -> str:
         """Marshals the object into a stringified JSON serialization. Keys are first sorted
